==> 0.0.1.tar.gz: android/src/main/java/com/aliyun/imp/flutter/classroom/alicloud_impinteraction_classroom/AlicloudImpinteractionClassroomPlugin.java <==
package com.aliyun.imp.flutter.classroom.alicloud_impinteraction_classroom;

import android.app.Activity;
import android.text.TextUtils;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.aliyun.roompaas.base.exposable.Callback;
import com.aliyun.roompaas.base.util.Utils;
import com.aliyun.roompaas.classroom.lib.core.ClassInitParam;
import com.aliyun.roompaas.classroom.lib.core.ClassPrototype;

import java.lang.ref.Reference;
import java.lang.ref.WeakReference;

import io.flutter.Log;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * AlicloudImpinteractionClassroomPlugin
 */
public class AlicloudImpinteractionClassroomPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
    public static final String TAG = "AlicloudImpinteractionClassroomPlugin";
    private MethodChannel channel;

    private Reference<Activity> activityRef;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "alicloud_impinteraction_classroom");
        channel.setMethodCallHandler(this);
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
        Utils.clear(activityRef);
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android version: " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equals("getBatteryLevel")) {
            result.success("Android getBatteryLevel: " + 80);
        } else if (call.method.equals("init")) {
            ClassInitParam param = new ClassInitParam();
            param.userId = call.argument("userId");
            param.appId = call.argument("appId");
            param.appKey = call.argument("appKey");
            param.serverHost = call.argument("serverHost");
            param.serverSecret = call.argument("serverSecret");
            init(param);
            result.success("Android init: ");
        } else if (call.method.equals("setUp")) {
            setUp(call.argument("classId"));
            result.success("Android setUp: " + 80);
        } else {
            result.notImplemented();
        }
    }

    private String getBatteryLevel() {
        setUp("5a4382b5-6f2b-436a-8785-5ac9edafb3c5");
        return "40";
    }

    private void init(ClassInitParam param) {
        Activity activity = Utils.getRef(activityRef);
        if (Utils.isActivityInvalid(activity)) {
            Log.i(TAG, "end : invalid activity:" + activityRef);
            return;
        }

        ClassPrototype.INSTANCE.init(activity, param, new Callback<Void>() {
            @Override
            public void onSuccess(Void data) {
                toast("INSTANCE.init onSuccess: " + data);
            }

            @Override
            public void onError(String errorMsg) {
                toast("INSTANCE.init onError: " + errorMsg);
            }
        });
    }

    private void setUp(@Nullable String classId) {
        Activity activity = Utils.getRef(activityRef);
        if (Utils.isActivityInvalid(activity) || TextUtils.isEmpty(classId)) {
            Log.i(TAG, "end : invalid activity:" + activityRef);
            return;
        }

        ClassPrototype.OpenClassParam classParam = new ClassPrototype.OpenClassParam();

        classParam.classId = classId;
        ClassPrototype.INSTANCE.setup(activity, classParam, new Callback<String>() {
            @Override
            public void onSuccess(String data) {
                toast("setUp onSuccess: " + data);
            }

            @Override
            public void onError(String errorMsg) {
                toast("setUp onError: " + errorMsg);
            }
        });
    }

    private void toast(String str) {
        Log.i(TAG, str);
        Activity activity = Utils.getRef(activityRef);
        if (Utils.isActivityInvalid(activity)) {
            Log.i(TAG, "end : invalid activity:" + activityRef);
            return;
        }

        Toast.makeText(activity, str, Toast.LENGTH_LONG).show();
    }

    @Override
    public void onAttachedToActivity(ActivityPluginBinding activityPluginBinding) {
        activityRef = activityPluginBinding != null ? new WeakReference<>(activityPluginBinding.getActivity()) : null;
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(ActivityPluginBinding activityPluginBinding) {

    }

    @Override
    public void onDetachedFromActivity() {
        Utils.clear(activityRef);
    }
}

==> 0.0.3.tar.gz: android/src/main/java/com/aliyun/imp/flutter/classroom/alicloud_impinteraction_classroom/AlicloudImpinteractionClassroomPlugin.java <==
package com.aliyun.imp.flutter.classroom.alicloud_impinteraction_classroom;

import android.app.Activity;
import android.text.TextUtils;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.aliyun.roompaas.base.exposable.Callback;
import com.aliyun.roompaas.base.util.Utils;
import com.aliyun.roompaas.classroom.lib.core.ClassInitParam;
import com.aliyun.roompaas.classroom.lib.core.ClassPrototype;

import java.lang.ref.Reference;
import java.lang.ref.WeakReference;

import io.flutter.Log;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * AlicloudImpinteractionClassroomPlugin
 */
public class AlicloudImpinteractionClassroomPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
    public static final String TAG = "AlicloudImpinteractionClassroomPlugin";
    private MethodChannel channel;

    private Reference<Activity> activityRef;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "alicloud_impinteraction_classroom");
        channel.setMethodCallHandler(this);
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
        Utils.clear(activityRef);
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android version: " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equals("getBatteryLevel")) {
            result.success("Android getBatteryLevel: " + 80);
        } else if (call.method.equals("init")) {
            ClassInitParam param = new ClassInitParam();
            param.userId = call.argument("userId");
            param.appId = call.argument("appId");
            param.appKey = call.argument("appKey4Android");
            param.serverHost = call.argument("serverHost");
            param.serverSecret = call.argument("serverSecret");
            init(param);
            result.success("Android init: ");
        } else if (call.method.equals("setUp")) {
            setUp(call.argument("classId"));
            result.success("Android setUp: " + 80);
        } else {
            result.notImplemented();
        }
    }

    private void init(ClassInitParam param) {
        Activity activity = Utils.getRef(activityRef);
        if (Utils.isActivityInvalid(activity)) {
            Log.i(TAG, "end : invalid activity:" + activityRef);
            return;
        }

        ClassPrototype.INSTANCE.init(activity, param, new Callback<Void>() {
            @Override
            public void onSuccess(Void data) {
                toast("INSTANCE.init onSuccess: " + data);
            }

            @Override
            public void onError(String errorMsg) {
                toast("INSTANCE.init onError: " + errorMsg);
            }
        });
    }

    private void setUp(@Nullable String classId) {
        Activity activity = Utils.getRef(activityRef);
        if (Utils.isActivityInvalid(activity) || TextUtils.isEmpty(classId)) {
            Log.i(TAG, "end : invalid activity:" + activityRef);
            return;
        }

        ClassPrototype.OpenClassParam classParam = new ClassPrototype.OpenClassParam();

        classParam.classId = classId;
        ClassPrototype.INSTANCE.setup(activity, classParam, new Callback<String>() {
            @Override
            public void onSuccess(String data) {
                toast("setUp onSuccess: " + data);
            }

            @Override
            public void onError(String errorMsg) {
                toast("setUp onError: " + errorMsg);
            }
        });
    }

    private void toast(String str) {
        Log.i(TAG, str);
        Activity activity = Utils.getRef(activityRef);
        if (Utils.isActivityInvalid(activity)) {
            Log.i(TAG, "end : invalid activity:" + activityRef);
            return;
        }

        Toast.makeText(activity, str, Toast.LENGTH_LONG).show();
    }

    @Override
    public void onAttachedToActivity(ActivityPluginBinding activityPluginBinding) {
        activityRef = activityPluginBinding != null ? new WeakReference<>(activityPluginBinding.getActivity()) : null;
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(ActivityPluginBinding activityPluginBinding) {

    }

    @Override
    public void onDetachedFromActivity() {
        Utils.clear(activityRef);
    }
}
